﻿using ApiDePaul.DTO;
using Microsoft.AspNetCore.Mvc;
using Model;
using StubLib;
using System.Collections.Generic;

namespace ApiDePaul.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class ChampionController : ControllerBase
    {
        IDataManager donnees = new StubData();

        private readonly ILogger<ChampionController> _logger;

        public ChampionController(ILogger<ChampionController> logger)
        {
            _logger = logger;
        }

        [HttpGet]
        public async Task<ActionResult<ChampionDto>> GetChamps()
        {
            IEnumerable<Champion?> lcha = await donnees.ChampionsMgr.GetItems(0, donnees.ChampionsMgr.GetNbItems().Result);

            List<ChampionDto> champs = new List<ChampionDto>();

            lcha.ToList().ForEach(c => champs.Add(c.ChampToDto()));
            return Ok(champs);
        }

        [HttpGet("{id}")]
        public async Task<ActionResult<ChampionDto>> GetChampId(int id)
        {
            IEnumerable<Champion?> lcha = await donnees.ChampionsMgr.GetItems(id, 1);

            if (id >= 0 && id < donnees.ChampionsMgr.GetNbItems().Result)
            {
                return Ok(lcha.First().ChampToDto());
            }
            return BadRequest();
        }


        [HttpGet("{id}/Skins")]
        public async Task<ActionResult<SkinDto>> GetSkinsChamp(int id)
        {
            IEnumerable<Champion?> lcha = await donnees.ChampionsMgr.GetItems(id, 1);

            if (id >= 0 && id < donnees.ChampionsMgr.GetNbItems().Result)
            {
                Champion ca = lcha.First();

                IEnumerable<Skin?> lsk = await donnees.SkinsMgr.GetItemsByChampion(ca, 0, donnees.SkinsMgr.GetNbItemsByChampion(ca).Result);

                List<SkinDto> skins = new List<SkinDto>();
                lsk.ToList().ForEach(s => skins.Add(s.SkinToDto()));

                return Ok(skins);
            }
            return BadRequest();
        }


        [HttpPost("Ajouter/{nom}")]
        public async Task<ActionResult> PostChampName(string nom)
        {
            Champion ca = new Champion(nom);

            await donnees.ChampionsMgr.AddItem(ca);

            return CreatedAtAction(nameof(GetChampId), new { id = donnees.ChampionsMgr.GetNbItems().Result - 1 }, ca.ChampToDto());
        }

        [HttpPost("Ajouter")]
        public async Task<IActionResult> PostChamp([FromBody] ChampionDto c)
        {
            Champion ca = c.DtoToChamp();
            await donnees.ChampionsMgr.AddItem(ca);
            return CreatedAtAction(nameof(donnees.ChampionsMgr.GetItemsByName), new { Name = c.Name }, c);
        }




        [HttpDelete("Supprimer/{id}")]
        public async Task<IActionResult> DeleteChamp(int id)
        {
            IEnumerable<Champion?> lcha = await donnees.ChampionsMgr.GetItems(id, 1);

            if (id >= 0 && id < donnees.ChampionsMgr.GetNbItems().Result)
            {
                Champion ca = lcha.First();
                donnees.ChampionsMgr.DeleteItem(ca);
                return Ok();
            }
            return BadRequest();
        }


        [HttpPut("Modifier/{nom}")]// CA C4EST PAS FINI
        public async Task<ActionResult> PutChampName(string nom)
        {
            Champion ca = new Champion(nom);

            await donnees.ChampionsMgr.AddItem(ca);

            return CreatedAtAction(nameof(GetChampId), new { id = donnees.ChampionsMgr.GetNbItems().Result - 1 }, ca.ChampToDto());
        }

        [HttpPut("Modifier")]
        public async Task<IActionResult> PutChamp([FromBody] ChampionDto c, [FromBody] ChampionDto cNouv)
        {
            Champion ca = c.DtoToChamp();
            Champion caNouv = cNouv.DtoToChamp();
            await donnees.ChampionsMgr.UpdateItem(ca,caNouv);
            return CreatedAtAction(nameof(GetChampId), new { id = donnees.ChampionsMgr.GetItems(0,donnees.ChampionsMgr.GetNbItems().Result).Result.ToList().IndexOf(ca) }, ca);
        }
    }
}
